@@ -341,7 +341,7 @@ class kafka_mdml_consumer:
             except KeyboardInterrupt:
                 break
         
-    def consume_chunks(self, poll_timeout=1.0, overall_timeout=300.0, save_file=True, save_dir='.'):
+    def consume_chunks(self, poll_timeout=1.0, overall_timeout=300.0, save_file=True, save_dir='.', passthrough=True):
         """
         Consume messages that were chunked and save the file to disk. 
         
@@ -355,6 +355,12 @@ class kafka_mdml_consumer:
         save_file : bool
             True if the chunked file should be saved. False will
             return the original data contained in the file
+        save_dir : str
+            Directory to save files
+        passthrough : bool
+            If multiple topics are subscribed to and one of them is 
+            not using chunking, passthrough=True will ensure those 
+            messages are still returned
         """
         print(f"Consumer loop will exit after {overall_timeout} seconds without receiving a message or with Ctrl+C")
         timeout = 0.0
@@ -373,6 +379,12 @@ class kafka_mdml_consumer:
                         self.deserializers[msg.topic()] = JSONDeserializer(schema_string)
                 timeout = 0.0
                 value = self.deserializers[msg.topic()](msg.value(), {})
+                if passthrough:
+                    if 'chunk' not in value:
+                        yield {
+                            'topic': msg.topic(),
+                            'value': value
+                        }
                 fn = value['filename']
                 part_info = value['part'].split('.')
                 if fn in files:
